==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, _super);
    function GeographicXYTriangulatingSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        if (a.g(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
        a.t("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicXYTriangulatingSeriesBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, _super);
    function GeographicXYTriangulatingSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
        a.z("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicXYTriangulatingSeriesBaseDescriptionMetadata };
